==> lxqt-powermanagement_1.2.0.orig.tar.xz: lxqt-powermanagement-1.2.0/config/translations/lxqt-config-powermanagement_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Configurações do monitor de bateria</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>A&amp;tivar monitor de bateria</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Aviso:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> segundos</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Nível baixo em:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>Pré-visualização</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>Carregando</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>Descarregando</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Em caso de baixa energia:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Exibir ícone:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>integrado</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>Nível: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Ativar monitor d&amp;e inatividade</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>Tempo para inatividade:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>Habilitar alteração de luz de fundo</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>Quando inativo na bateria:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation>Tempo de inatividade na bateria:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>Luz de fundo (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>Minutos:segundos</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>mm:ss</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>Quando inativo na tomada:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>Tempo de inatividade na tomada:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>Minutos:segundos (min: 01:30)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation>Verificar luz de fundo</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation>Na bateria descarregando </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>Desabilitar verificações de inatividade quando em tela cheia</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Ativar monitor da &amp;tampa</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>Ação ao fechar a tampa:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>Com bateria:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>Não fazer nada</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>Na tomada:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>Ao &amp;utilizar monitor externo</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>Configurações do gerenciador de energia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>Bateria</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>Tampa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>Inatividade</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>Botões de energia</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>Lidar com botões de energia</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>Ação do botão de energia:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>Ação do botão de suspender:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>Ação do botão de hibernar:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Não fazer nada</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Lock screen</source>
        <translation>Bloquear tela</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Turn Off monitor(s)</source>
        <translation>Desativar monitor(es)</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_1.3.0.orig.tar.xz: lxqt-powermanagement-1.3.0/config/translations/lxqt-config-powermanagement_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Configurações do monitor de bateria</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>A&amp;tivar monitor de bateria</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Aviso:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> segundos</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Nível baixo em:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>Ícone:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>Pré-visualização</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>Carregando</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>Descarregando</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Em caso de baixa energia:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Exibir ícone:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>do tema</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>Círculo</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>Círculo com porcentagem</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>Bateria com porcentagem e fundo</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>Bateria com porcentagem</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>integrado</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>Nível: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Ativar monitor d&amp;e inatividade</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>Tempo para inatividade:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>Habilitar alteração de luz de fundo</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>Quando inativo na bateria:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation>Tempo de inatividade na bateria:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>Luz de fundo (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>Minutos:segundos</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>mm:ss</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>Quando inativo na tomada:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>Tempo de inatividade na tomada:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>Minutos:segundos (min: 01:30)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation>Verificar luz de fundo</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation>Na bateria descarregando </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>Desabilitar verificações de inatividade quando em tela cheia</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Ativar monitor da &amp;tampa</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>Ação ao fechar a tampa:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>Com bateria:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>Não fazer nada</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>Na tomada:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>Ao &amp;utilizar monitor externo</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>Configurações do gerenciador de energia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>Bateria</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>Tampa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>Inatividade</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>Botões de energia</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>Lidar com botões de energia</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>Ação do botão de energia:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>Ação do botão de suspender:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>Ação do botão de hibernar:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Não fazer nada</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Lock screen</source>
        <translation>Bloquear tela</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Turn Off monitor(s)</source>
        <translation>Desativar monitor(es)</translation>
    </message>
</context>
</TS>
